.. currentmodule:: pdcast

pandas.Series.element_type
==========================

.. property:: pandas.Series.element_type

    The inferred element type of the series.  This is equivalent to running
    :func:`detect_type` on the series.

    This property is defined for every type.
